//
// "$Id: ppdc-file.cxx 251 2005-06-17 02:53:12Z mike $"
//
//   File class for the CUPS PPD Compiler.
//
//   Copyright 2002-2005 by Easy Software Products.
//
//   These coded instructions, statements, and computer programs are the
//   property of Easy Software Products and are protected by Federal
//   copyright law.  Distribution and use rights are outlined in the file
//   "LICENSE.txt" which should have been included with this file.  If this
//   file is missing or damaged please contact Easy Software Products
//   at:
//
//       Attn: CUPS Licensing Information
//       Easy Software Products
//       44141 Airport View Drive, Suite 204
//       Hollywood, Maryland 20636 USA
//
//       Voice: (301) 373-9600
//       EMail: cups-info@cups.org
//         WWW: http://www.cups.org
//
// Contents:
//
//   ppdcFile::ppdcFile()  - Create (open) a file.
//   ppdcFile::~ppdcFile() - Delete (close) a file.
//   ppdcFile::get()       - Get a character from a file.
//   ppdcFile::unget()     - Restore a character from a file.
//

//
// Include necessary headers...
//

#include "ppdc.h"


//
// 'ppdcFile::ppdcFile()' - Create (open) a file.
//

ppdcFile::ppdcFile(const char *f)		// I - File to open
{
  fp       = fopen(f, "rb");
  filename = f;
  line     = 1;

  if (!fp)
    fprintf(stderr, "ppdc: Unable to open %s: %s\n", f, strerror(errno));
}


//
// 'ppdcFile::~ppdcFile()' - Delete (close) a file.
//

ppdcFile::~ppdcFile()
{
  if (fp)
    fclose(fp);
}


//
// 'ppdcFile::get()' - Get a character from a file.
//

int
ppdcFile::get()
{
  int	ch;					// Character from file


  // Return EOF if there is no open file...
  if (!fp)
    return (EOF);

  // Get the character...
  ch = getc(fp);

  // Update the line number as needed...
  if (ch == '\n')
    line ++;

  // Return the character...
  return (ch);
}


//
// 'ppdcFile::unget()' - Restore a character from a file.
//

void
ppdcFile::unget(int ch)				// I - Character to restore
{
  // Return immediaely if there is no open file...
  if (!fp)
    return;

  // Update the line number as needed...
  if (ch == '\n')
    line --;

  // Unget the character...
  ungetc(ch, fp);
}


//
// End of "$Id: ppdc-file.cxx 251 2005-06-17 02:53:12Z mike $".
//
